=====
si4ul
=====

This package implements selecrtive inference for unsupervised learning.

- image segmentation
- k-means
- change-point detection

Key references are the following papers:

-  `Computing Valid p-values for Image Segmentation by Selective Inference <https://openaccess.thecvf.com/content_CVPR_2020/papers/Tanizaki_Computing_Valid_P-Values_for_Image_Segmentation_by_Selective_Inference_CVPR_2020_paper.pdf>`_
-  `Computing Valid p-value for Optimal Changepoint by Selective Inference using Dynamic Programming <https://arxiv.org/pdf/2002.09132.pdf>`_


Requirements
============
This package requires the following packages:

- matplotlib
- mpmath
- numpy
- opencv-python
- pandas
- scipy
- seaborn
- statsmodels
- tqdm


Installing si4ul
==============================
Use pip to install si4ul package. 
Required packages will be also installed automatically.

.. code-block:: console
    
    $ pip install si4ul

=============
API Reference
=============
`Detailed API reference is available here <https://github.com/takeuchi-lab/si4ul/blob/main/document.pdf>`_
